Module directedgraph

Module directedgraph 

Basic definitions for directed graphs

Structs

Neighbors
An iterator through the neighbors of a given node (nodes reachable by a single edge transition from the given node) in a graph.

Traits

DirectedGraph
The trait for types (implicitly or explicitly) representing a directed graph structure
OutboundEdge
The trait for types representing a single graph edge from a known graph node