OutboundEdge

Trait OutboundEdge 

pub trait OutboundEdge<N> {
    // Required method
    fn destination(&self) -> N;

    // Provided method
    fn into_destination(self) -> N
       where Self: Sized { ... }
}
The trait for types representing a single graph edge from a known graph node

This could be a reference to some internal part of your data structure, an index or whatever else is suitable for your graph representation.

Required Methods

fn destination(&self) -> N

Returns the destination node of self

Provided Methods

fn into_destination(self) -> N
where Self: Sized,

Consume self and return its destination node instead

Implementors