Basic definitions for directed graphs
Structs
- Neighbors
- An iterator through the neighbors of a given node (nodes reachable by a single edge transition from the given node) in a graph.
Traits
- Directed
Graph - The trait for types (implicitly or explicitly) representing a directed graph structure
- Outbound
Edge - The trait for types representing a single graph edge from a known graph node